import sys
from datetime import datetime, timedelta

if sys.version_info < (3,):
    intBase = long
else:
    intBase = int


class GlobalID(intBase):
    """
    Represents a globally unique identifier within the Steam network.
    Guaranteed to be unique across all racks and servers for a given Steam universe.
    """
    def __new__(cls, *args, **kwargs):
        if len(args) == 1:
            return super(GlobalID, cls).__new__(cls, *args)

        gid = GlobalID.new(*args, **kwargs)
        return super(GlobalID, cls).__new__(cls, gid)

    @staticmethod
    def new(sequence_count, start_time, process_id, box_id):
        """Make new GlobalID

        :param sequence_count: sequence count
        :type sequence_count: :class:`int`
        :param start_time: start date time of server (must be after 2005-01-01)
        :type start_time: :class:`str`, :class:`datetime`
        :param process_id: process id
        :type process_id: :class:`int`
        :param box_id: box id
        :type box_id: :class:`int`
        :return: Global ID integer
        :rtype: :class:`int`
        """
        if not isinstance(start_time, datetime):
            start_time = datetime.strptime(start_time, '%Y-%m-%d %H:%M:%S')
        start_time_seconds = int((start_time - datetime(2005, 1, 1)).total_seconds())

        return (box_id << 54) | (process_id << 50) | (start_time_seconds << 20) | sequence_count

    def __init__(self, *args, **kwargs):
        pass

    def __repr__(self):
        return "%s(sequence_count=%s, start_time=%s, process_id=%s, box_id=%s)" % (
            self.__class__.__name__,
            self.sequence_count,
            repr(str(self.start_time)),
            self.process_id,
            self.box_id,
            )

    @property
    def sequence_count(self):
        """
        :return: sequence count for GID
        :rtype: :class:`int`
        """
        return self & 0xFFFFF

    @property
    def start_time_seconds(self):
        """
        :return: seconds since 2005-01-01
        :rtype: :class:`int`
        """
        return (self >> 20) & 0x3FFFFFFF

    @property
    def start_time(self):
        """
        :return: start time of the server that generated this GID
        :rtype: :class:`datetime`
        """
        return datetime(2005, 1, 1) + timedelta(seconds=self.start_time_seconds)

    @property
    def process_id(self):
        """
        :return: process id of server
        :rtype: :class:`int`
        """
        return (self >> 50) & 0xF

    @property
    def box_id(self):
        """
        :return: box id of server
        :rtype: :class:`int`
        """
        return (self >> 54) & 0x3FF



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_star.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_star.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18steammessages_star.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xc6\x01\n\x13\x43STAR_KeyValueQuery\x12\x43\n\x03key\x18\x01 \x01(\tB6\x82\xb5\x18\x32key to search for in JSON path format (SQL subset)\x12j\n\x05value\x18\x02 \x01(\tB[\x82\xb5\x18Wthe value to compare against (the JSON value will be compared for equality as a string)\"\xcb\x01\n\x16\x43STAR_GlyphQueryParams\x12s\n\tbundle_id\x18\x01 \x01(\x04\x42`\x82\xb5\x18\\if provided, Bundle ID is used instead of the other query parameters (much faster SQL query)\x12<\n\x07queries\x18\x02 \x03(\x0b\x32\x14.CSTAR_KeyValueQueryB\x15\x82\xb5\x18\x11key value queries\"\x94\x02\n\x1b\x43STAR_ReadGlyphData_Request\x12\x65\n\x0cquery_params\x18\x01 \x01(\x0b\x32\x17.CSTAR_GlyphQueryParamsB6\x82\xb5\x18\x32parameters to identify the glyphs to read from SQL\x12\x8d\x01\n\x1elast_modified_time_lower_limit\x18\x02 \x01(\tBe\x82\xb5\x18\x61if provided, only return glyphs modified more recently than this timestamp  (RFC 3339 UTC format)\"\xec\x01\n\x0f\x43STAR_GlyphData\x12<\n\nglyph_guid\x18\x01 \x01(\x0c\x42(\x82\xb5\x18$GUID uniquely identifying this glyph\x12\x65\n\x13glyph_last_modified\x18\x02 \x01(\tBH\x82\xb5\x18\x44timestamp of when this glyph was last modified (RFC 3339 UTC format)\x12\x34\n\x0fglyph_json_data\x18\x03 \x01(\tB\x1b\x82\xb5\x18\x17JSON encoded glyph data\"\xb4\x01\n\x1c\x43STAR_WriteGlyphData_Request\x12@\n\tbundle_id\x18\x01 \x01(\x04\x42-\x82\xb5\x18)the Bundle ID of the glyphs to be written\x12R\n\nglyph_data\x18\x02 \x03(\x0b\x32\x10.CSTAR_GlyphDataB,\x82\xb5\x18(one or more items of glyph data to write\"\x7f\n\rCSTAR_Request\x12\x35\n\x0fread_glyph_data\x18\x01 \x01(\x0b\x32\x1c.CSTAR_ReadGlyphData_Request\x12\x37\n\x10write_glyph_data\x18\x02 \x01(\x0b\x32\x1d.CSTAR_WriteGlyphData_Request\"\xf1\x01\n\x1c\x43STAR_ReadGlyphData_Response\x12|\n\tbundle_id\x18\x01 \x01(\x04\x42i\x82\xb5\x18\x65the Bundle ID of the returned glyphs; the client should send this back to optimize subsequent queries\x12S\n\nglyph_data\x18\x02 \x03(\x0b\x32\x10.CSTAR_GlyphDataB-\x82\xb5\x18)zero or more items of returned glyph data\"w\n\x1d\x43STAR_WriteGlyphData_Response\x12V\n\x06result\x18\x01 \x03(\x0e\x32\x18.E_STAR_GlyphWriteResultB,\x82\xb5\x18(write result for each item of glyph data\"\x82\x01\n\x0e\x43STAR_Response\x12\x36\n\x0fread_glyph_data\x18\x01 \x01(\x0b\x32\x1d.CSTAR_ReadGlyphData_Response\x12\x38\n\x10write_glyph_data\x18\x02 \x01(\x0b\x32\x1e.CSTAR_WriteGlyphData_Response*\xc1\x01\n\x17\x45_STAR_GlyphWriteResult\x12%\n!k_E_STAR_GlyphWriteResult_Success\x10\x00\x12,\n(k_E_STAR_GlyphWriteResult_InvalidMessage\x10\x01\x12)\n%k_E_STAR_GlyphWriteResult_InvalidJSON\x10\x02\x12&\n\"k_E_STAR_GlyphWriteResult_SQLError\x10\x03\x32\x85\x01\n\x04STAR\x12R\n\x0eProcessMessage\x12\x0e.CSTAR_Request\x1a\x0f.CSTAR_Response\"\x1f\x82\xb5\x18\x1bprocesses a generic message\x1a)\x82\xb5\x18%service for reading/writing STAR dataB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_E_STAR_GLYPHWRITERESULT = _descriptor.EnumDescriptor(
  name='E_STAR_GlyphWriteResult',
  full_name='E_STAR_GlyphWriteResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_E_STAR_GlyphWriteResult_Success', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_E_STAR_GlyphWriteResult_InvalidMessage', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_E_STAR_GlyphWriteResult_InvalidJSON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_E_STAR_GlyphWriteResult_SQLError', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1824,
  serialized_end=2017,
)
_sym_db.RegisterEnumDescriptor(_E_STAR_GLYPHWRITERESULT)

E_STAR_GlyphWriteResult = enum_type_wrapper.EnumTypeWrapper(_E_STAR_GLYPHWRITERESULT)
k_E_STAR_GlyphWriteResult_Success = 0
k_E_STAR_GlyphWriteResult_InvalidMessage = 1
k_E_STAR_GlyphWriteResult_InvalidJSON = 2
k_E_STAR_GlyphWriteResult_SQLError = 3



_CSTAR_KEYVALUEQUERY = _descriptor.Descriptor(
  name='CSTAR_KeyValueQuery',
  full_name='CSTAR_KeyValueQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CSTAR_KeyValueQuery.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302key to search for in JSON path format (SQL subset)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CSTAR_KeyValueQuery.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Wthe value to compare against (the JSON value will be compared for equality as a string)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=287,
)


_CSTAR_GLYPHQUERYPARAMS = _descriptor.Descriptor(
  name='CSTAR_GlyphQueryParams',
  full_name='CSTAR_GlyphQueryParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='CSTAR_GlyphQueryParams.bundle_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\\if provided, Bundle ID is used instead of the other query parameters (much faster SQL query)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries', full_name='CSTAR_GlyphQueryParams.queries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021key value queries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=493,
)


_CSTAR_READGLYPHDATA_REQUEST = _descriptor.Descriptor(
  name='CSTAR_ReadGlyphData_Request',
  full_name='CSTAR_ReadGlyphData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_params', full_name='CSTAR_ReadGlyphData_Request.query_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302parameters to identify the glyphs to read from SQL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_modified_time_lower_limit', full_name='CSTAR_ReadGlyphData_Request.last_modified_time_lower_limit', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030aif provided, only return glyphs modified more recently than this timestamp  (RFC 3339 UTC format)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=772,
)


_CSTAR_GLYPHDATA = _descriptor.Descriptor(
  name='CSTAR_GlyphData',
  full_name='CSTAR_GlyphData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='glyph_guid', full_name='CSTAR_GlyphData.glyph_guid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$GUID uniquely identifying this glyph', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glyph_last_modified', full_name='CSTAR_GlyphData.glyph_last_modified', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Dtimestamp of when this glyph was last modified (RFC 3339 UTC format)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glyph_json_data', full_name='CSTAR_GlyphData.glyph_json_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027JSON encoded glyph data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=1011,
)


_CSTAR_WRITEGLYPHDATA_REQUEST = _descriptor.Descriptor(
  name='CSTAR_WriteGlyphData_Request',
  full_name='CSTAR_WriteGlyphData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='CSTAR_WriteGlyphData_Request.bundle_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)the Bundle ID of the glyphs to be written', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glyph_data', full_name='CSTAR_WriteGlyphData_Request.glyph_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030(one or more items of glyph data to write', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1194,
)


_CSTAR_REQUEST = _descriptor.Descriptor(
  name='CSTAR_Request',
  full_name='CSTAR_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_glyph_data', full_name='CSTAR_Request.read_glyph_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_glyph_data', full_name='CSTAR_Request.write_glyph_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1323,
)


_CSTAR_READGLYPHDATA_RESPONSE = _descriptor.Descriptor(
  name='CSTAR_ReadGlyphData_Response',
  full_name='CSTAR_ReadGlyphData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='CSTAR_ReadGlyphData_Response.bundle_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ethe Bundle ID of the returned glyphs; the client should send this back to optimize subsequent queries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glyph_data', full_name='CSTAR_ReadGlyphData_Response.glyph_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)zero or more items of returned glyph data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1567,
)


_CSTAR_WRITEGLYPHDATA_RESPONSE = _descriptor.Descriptor(
  name='CSTAR_WriteGlyphData_Response',
  full_name='CSTAR_WriteGlyphData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CSTAR_WriteGlyphData_Response.result', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030(write result for each item of glyph data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1569,
  serialized_end=1688,
)


_CSTAR_RESPONSE = _descriptor.Descriptor(
  name='CSTAR_Response',
  full_name='CSTAR_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_glyph_data', full_name='CSTAR_Response.read_glyph_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_glyph_data', full_name='CSTAR_Response.write_glyph_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1821,
)

_CSTAR_GLYPHQUERYPARAMS.fields_by_name['queries'].message_type = _CSTAR_KEYVALUEQUERY
_CSTAR_READGLYPHDATA_REQUEST.fields_by_name['query_params'].message_type = _CSTAR_GLYPHQUERYPARAMS
_CSTAR_WRITEGLYPHDATA_REQUEST.fields_by_name['glyph_data'].message_type = _CSTAR_GLYPHDATA
_CSTAR_REQUEST.fields_by_name['read_glyph_data'].message_type = _CSTAR_READGLYPHDATA_REQUEST
_CSTAR_REQUEST.fields_by_name['write_glyph_data'].message_type = _CSTAR_WRITEGLYPHDATA_REQUEST
_CSTAR_READGLYPHDATA_RESPONSE.fields_by_name['glyph_data'].message_type = _CSTAR_GLYPHDATA
_CSTAR_WRITEGLYPHDATA_RESPONSE.fields_by_name['result'].enum_type = _E_STAR_GLYPHWRITERESULT
_CSTAR_RESPONSE.fields_by_name['read_glyph_data'].message_type = _CSTAR_READGLYPHDATA_RESPONSE
_CSTAR_RESPONSE.fields_by_name['write_glyph_data'].message_type = _CSTAR_WRITEGLYPHDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CSTAR_KeyValueQuery'] = _CSTAR_KEYVALUEQUERY
DESCRIPTOR.message_types_by_name['CSTAR_GlyphQueryParams'] = _CSTAR_GLYPHQUERYPARAMS
DESCRIPTOR.message_types_by_name['CSTAR_ReadGlyphData_Request'] = _CSTAR_READGLYPHDATA_REQUEST
DESCRIPTOR.message_types_by_name['CSTAR_GlyphData'] = _CSTAR_GLYPHDATA
DESCRIPTOR.message_types_by_name['CSTAR_WriteGlyphData_Request'] = _CSTAR_WRITEGLYPHDATA_REQUEST
DESCRIPTOR.message_types_by_name['CSTAR_Request'] = _CSTAR_REQUEST
DESCRIPTOR.message_types_by_name['CSTAR_ReadGlyphData_Response'] = _CSTAR_READGLYPHDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CSTAR_WriteGlyphData_Response'] = _CSTAR_WRITEGLYPHDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CSTAR_Response'] = _CSTAR_RESPONSE
DESCRIPTOR.enum_types_by_name['E_STAR_GlyphWriteResult'] = _E_STAR_GLYPHWRITERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CSTAR_KeyValueQuery = _reflection.GeneratedProtocolMessageType('CSTAR_KeyValueQuery', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_KEYVALUEQUERY,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_KeyValueQuery)
  })
_sym_db.RegisterMessage(CSTAR_KeyValueQuery)

CSTAR_GlyphQueryParams = _reflection.GeneratedProtocolMessageType('CSTAR_GlyphQueryParams', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_GLYPHQUERYPARAMS,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_GlyphQueryParams)
  })
_sym_db.RegisterMessage(CSTAR_GlyphQueryParams)

CSTAR_ReadGlyphData_Request = _reflection.GeneratedProtocolMessageType('CSTAR_ReadGlyphData_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_READGLYPHDATA_REQUEST,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_ReadGlyphData_Request)
  })
_sym_db.RegisterMessage(CSTAR_ReadGlyphData_Request)

CSTAR_GlyphData = _reflection.GeneratedProtocolMessageType('CSTAR_GlyphData', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_GLYPHDATA,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_GlyphData)
  })
_sym_db.RegisterMessage(CSTAR_GlyphData)

CSTAR_WriteGlyphData_Request = _reflection.GeneratedProtocolMessageType('CSTAR_WriteGlyphData_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_WRITEGLYPHDATA_REQUEST,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_WriteGlyphData_Request)
  })
_sym_db.RegisterMessage(CSTAR_WriteGlyphData_Request)

CSTAR_Request = _reflection.GeneratedProtocolMessageType('CSTAR_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_REQUEST,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_Request)
  })
_sym_db.RegisterMessage(CSTAR_Request)

CSTAR_ReadGlyphData_Response = _reflection.GeneratedProtocolMessageType('CSTAR_ReadGlyphData_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_READGLYPHDATA_RESPONSE,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_ReadGlyphData_Response)
  })
_sym_db.RegisterMessage(CSTAR_ReadGlyphData_Response)

CSTAR_WriteGlyphData_Response = _reflection.GeneratedProtocolMessageType('CSTAR_WriteGlyphData_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_WRITEGLYPHDATA_RESPONSE,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_WriteGlyphData_Response)
  })
_sym_db.RegisterMessage(CSTAR_WriteGlyphData_Response)

CSTAR_Response = _reflection.GeneratedProtocolMessageType('CSTAR_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTAR_RESPONSE,
  '__module__' : 'steammessages_star_pb2'
  # @@protoc_insertion_point(class_scope:CSTAR_Response)
  })
_sym_db.RegisterMessage(CSTAR_Response)


DESCRIPTOR._options = None
_CSTAR_KEYVALUEQUERY.fields_by_name['key']._options = None
_CSTAR_KEYVALUEQUERY.fields_by_name['value']._options = None
_CSTAR_GLYPHQUERYPARAMS.fields_by_name['bundle_id']._options = None
_CSTAR_GLYPHQUERYPARAMS.fields_by_name['queries']._options = None
_CSTAR_READGLYPHDATA_REQUEST.fields_by_name['query_params']._options = None
_CSTAR_READGLYPHDATA_REQUEST.fields_by_name['last_modified_time_lower_limit']._options = None
_CSTAR_GLYPHDATA.fields_by_name['glyph_guid']._options = None
_CSTAR_GLYPHDATA.fields_by_name['glyph_last_modified']._options = None
_CSTAR_GLYPHDATA.fields_by_name['glyph_json_data']._options = None
_CSTAR_WRITEGLYPHDATA_REQUEST.fields_by_name['bundle_id']._options = None
_CSTAR_WRITEGLYPHDATA_REQUEST.fields_by_name['glyph_data']._options = None
_CSTAR_READGLYPHDATA_RESPONSE.fields_by_name['bundle_id']._options = None
_CSTAR_READGLYPHDATA_RESPONSE.fields_by_name['glyph_data']._options = None
_CSTAR_WRITEGLYPHDATA_RESPONSE.fields_by_name['result']._options = None

_STAR = _descriptor.ServiceDescriptor(
  name='STAR',
  full_name='STAR',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030%service for reading/writing STAR data',
  create_key=_descriptor._internal_create_key,
  serialized_start=2020,
  serialized_end=2153,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessMessage',
    full_name='STAR.ProcessMessage',
    index=0,
    containing_service=None,
    input_type=_CSTAR_REQUEST,
    output_type=_CSTAR_RESPONSE,
    serialized_options=b'\202\265\030\033processes a generic message',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STAR)

DESCRIPTOR.services_by_name['STAR'] = _STAR

STAR = service_reflection.GeneratedServiceType('STAR', (_service.Service,), dict(
  DESCRIPTOR = _STAR,
  __module__ = 'steammessages_star_pb2'
  ))

STAR_Stub = service_reflection.GeneratedServiceStubType('STAR_Stub', (STAR,), dict(
  DESCRIPTOR = _STAR,
  __module__ = 'steammessages_star_pb2'
  ))


# @@protoc_insertion_point(module_scope)



"""
Appache file parsing examples:

.. code:: python

    >>> from steam.utils.appcache import parse_appinfo, parse_packageinfo

    >>> header, apps = parse_appinfo(open('/d/Steam/appcache/appinfo.vdf', 'rb'))
    >>> header
    {'magic': b"'DV\\x07", 'universe': 1}
    >>> next(apps)
    {'appid': 5,
     'size': 79,
     'info_state': 1,
     'last_updated': 1484735377,
     'access_token': 0,
     'sha1': b'\\x87\\xfaCg\\x85\\x80\\r\\xb4\\x90Im\\xdc}\\xb4\\x81\\xeeQ\\x8b\\x825',
     'change_number': 4603827,
     'data': {'appinfo': {'appid': 5, 'public_only': 1}}}

    >>> header, pkgs = parse_packageinfo(open('/d/Steam/appcache/packageinfo.vdf', 'rb'))
    >>> header
    {'magic': b"'UV\\x06", 'universe': 1}

    >>> next(pkgs)
    {'packageid': 7,
     'sha1': b's\\x8b\\xf7n\\t\\xe5 k#\\xb6-\\x82\\xd2 \\x14k@\\xfeDQ',
     'change_number': 7469765,
     'data': {'7': {'packageid': 7,
       'billingtype': 1,
       'licensetype': 1,
       'status': 0,
       'extended': {'requirespreapproval': 'WithRedFlag'},
       'appids': {'0': 10, '1': 80, '2': 100, '3': 254430},
       'depotids': {'0': 0, '1': 95, '2': 101, '3': 102, '4': 103, '5': 254431},
       'appitems': {}}}}

"""

import struct
from vdf import binary_load

uint32 = struct.Struct('<I')
uint64 = struct.Struct('<Q')

def parse_appinfo(fp):
    """Parse appinfo.vdf from the Steam appcache folder

    :param fp: file-like object
    :raises: SyntaxError
    :rtype: (:class:`dict`, :class:`Generator`)
    :return: (header, apps iterator)
    """
# format:
#   uint32   - MAGIC: "'DV\x07"
#   uint32   - UNIVERSE: 1
#   ---- repeated app sections ----
#   uint32   - AppID
#   uint32   - size
#   uint32   - infoState
#   uint32   - lastUpdated
#   uint64   - accessToken
#   20bytes  - SHA1
#   uint32   - changeNumber
#   variable - binary_vdf
#   ---- end of section ---------
#   uint32   - EOF: 0

    magic = fp.read(4)
    if magic != b"'DV\x07":
        raise SyntaxError("Invalid magic, got %s" % repr(magic))

    universe = uint32.unpack(fp.read(4))[0]

    def apps_iter():
        while True:
            appid = uint32.unpack(fp.read(4))[0]

            if appid == 0:
                break

            app = {
                'appid': appid,
                'size': uint32.unpack(fp.read(4))[0],
                'info_state': uint32.unpack(fp.read(4))[0],
                'last_updated': uint32.unpack(fp.read(4))[0],
                'access_token': uint64.unpack(fp.read(8))[0],
                'sha1': fp.read(20),
                'change_number': uint32.unpack(fp.read(4))[0],
                'data': binary_load(fp),
            }

            yield app


    return ({
              'magic': magic,
              'universe': universe,
            },
            apps_iter()
            )

def parse_packageinfo(fp):
    """Parse packageinfo.vdf from the Steam appcache folder

    :param fp: file-like object
    :raises: SyntaxError
    :rtype: (:class:`dict`, :class:`Generator`)
    :return: (header, packages iterator)
    """
# format:
#   uint32   - MAGIC: b"'UV\x06" or b"(UV\x06"
#   uint32   - UNIVERSE: 1
#   ---- repeated package sections ----
#   uint32   - PackageID
#   20bytes  - SHA1
#   uint32   - changeNumber
#   uint64   - token           (only on b"(UV\x06")
#   variable - binary_vdf
#   ---- end of section ---------
#   uint32   - EOF: 0xFFFFFFFF

    magic = fp.read(4)
    if magic not in (b"'UV\x06", b"(UV\x06"):
        raise SyntaxError("Invalid magic, got %s" % repr(magic))

    universe = uint32.unpack(fp.read(4))[0]

    def pkgs_iter():
        while True:
            packageid = uint32.unpack(fp.read(4))[0]

            if packageid == 0xFFFFFFFF:
                break

            pkg = {
                'packageid': packageid,
                'sha1': fp.read(20),
                'change_number': uint32.unpack(fp.read(4))[0],
            }

            if magic == b"(UV\x06":
                pkg['token'] = uint64.unpack(fp.read(8))[0]

            pkg['data'] = binary_load(fp)

            yield pkg


    return ({
              'magic': magic,
              'universe': universe,
            },
            pkgs_iter()
            )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_lbs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_lbs.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_clientserver_lbs.proto\x1a\x18steammessages_base.proto\"|\n\x15\x43MsgClientLBSSetScore\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\r\n\x05score\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x0c\x12\x1b\n\x13upload_score_method\x18\x05 \x01(\x05\"\xa2\x01\n\x1d\x43MsgClientLBSSetScoreResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17leaderboard_entry_count\x18\x02 \x01(\x05\x12\x15\n\rscore_changed\x18\x03 \x01(\x08\x12\x1c\n\x14global_rank_previous\x18\x04 \x01(\x05\x12\x17\n\x0fglobal_rank_new\x18\x05 \x01(\x05\"M\n\x13\x43MsgClientLBSSetUGC\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x0e\n\x06ugc_id\x18\x03 \x01(\x06\"1\n\x1b\x43MsgClientLBSSetUGCResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\xa7\x01\n\x1b\x43MsgClientLBSFindOrCreateLB\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1f\n\x17leaderboard_sort_method\x18\x02 \x01(\x05\x12 \n\x18leaderboard_display_type\x18\x03 \x01(\x05\x12\x1b\n\x13\x63reate_if_not_found\x18\x04 \x01(\x08\x12\x18\n\x10leaderboard_name\x18\x05 \x01(\t\"\xd5\x01\n#CMsgClientLBSFindOrCreateLBResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x1f\n\x17leaderboard_entry_count\x18\x03 \x01(\x05\x12\"\n\x17leaderboard_sort_method\x18\x04 \x01(\x05:\x01\x30\x12#\n\x18leaderboard_display_type\x18\x05 \x01(\x05:\x01\x30\x12\x18\n\x10leaderboard_name\x18\x06 \x01(\t\"\x9f\x01\n\x19\x43MsgClientLBSGetLBEntries\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x13\n\x0brange_start\x18\x03 \x01(\x05\x12\x11\n\trange_end\x18\x04 \x01(\x05\x12 \n\x18leaderboard_data_request\x18\x05 \x01(\x05\x12\x10\n\x08steamids\x18\x06 \x03(\x06\"\xf8\x01\n!CMsgClientLBSGetLBEntriesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17leaderboard_entry_count\x18\x02 \x01(\x05\x12\x39\n\x07\x65ntries\x18\x03 \x03(\x0b\x32(.CMsgClientLBSGetLBEntriesResponse.Entry\x1a\x63\n\x05\x45ntry\x12\x15\n\rsteam_id_user\x18\x01 \x01(\x06\x12\x13\n\x0bglobal_rank\x18\x02 \x01(\x05\x12\r\n\x05score\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x0c\x12\x0e\n\x06ugc_id\x18\x05 \x01(\x06\x42\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTLBSSETSCORE = _descriptor.Descriptor(
  name='CMsgClientLBSSetScore',
  full_name='CMsgClientLBSSetScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSSetScore.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSSetScore.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgClientLBSSetScore.score', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='CMsgClientLBSSetScore.details', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_score_method', full_name='CMsgClientLBSSetScore.upload_score_method', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=190,
)


_CMSGCLIENTLBSSETSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSSetScoreResponse',
  full_name='CMsgClientLBSSetScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSSetScoreResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSSetScoreResponse.leaderboard_entry_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_changed', full_name='CMsgClientLBSSetScoreResponse.score_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_rank_previous', full_name='CMsgClientLBSSetScoreResponse.global_rank_previous', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_rank_new', full_name='CMsgClientLBSSetScoreResponse.global_rank_new', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=355,
)


_CMSGCLIENTLBSSETUGC = _descriptor.Descriptor(
  name='CMsgClientLBSSetUGC',
  full_name='CMsgClientLBSSetUGC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSSetUGC.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSSetUGC.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ugc_id', full_name='CMsgClientLBSSetUGC.ugc_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=434,
)


_CMSGCLIENTLBSSETUGCRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSSetUGCResponse',
  full_name='CMsgClientLBSSetUGCResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSSetUGCResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=485,
)


_CMSGCLIENTLBSFINDORCREATELB = _descriptor.Descriptor(
  name='CMsgClientLBSFindOrCreateLB',
  full_name='CMsgClientLBSFindOrCreateLB',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSFindOrCreateLB.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_sort_method', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_sort_method', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_display_type', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_display_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_if_not_found', full_name='CMsgClientLBSFindOrCreateLB.create_if_not_found', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_name', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=655,
)


_CMSGCLIENTLBSFINDORCREATELBRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSFindOrCreateLBResponse',
  full_name='CMsgClientLBSFindOrCreateLBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSFindOrCreateLBResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_entry_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_sort_method', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_sort_method', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_display_type', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_display_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_name', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=871,
)


_CMSGCLIENTLBSGETLBENTRIES = _descriptor.Descriptor(
  name='CMsgClientLBSGetLBEntries',
  full_name='CMsgClientLBSGetLBEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSGetLBEntries.app_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSGetLBEntries.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_start', full_name='CMsgClientLBSGetLBEntries.range_start', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='CMsgClientLBSGetLBEntries.range_end', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_data_request', full_name='CMsgClientLBSGetLBEntries.leaderboard_data_request', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamids', full_name='CMsgClientLBSGetLBEntries.steamids', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=1033,
)


_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='CMsgClientLBSGetLBEntriesResponse.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.steam_id_user', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_rank', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.global_rank', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.score', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.details', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ugc_id', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.ugc_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1284,
)

_CMSGCLIENTLBSGETLBENTRIESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSGetLBEntriesResponse',
  full_name='CMsgClientLBSGetLBEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSGetLBEntriesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSGetLBEntriesResponse.leaderboard_entry_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgClientLBSGetLBEntriesResponse.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1284,
)

_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY.containing_type = _CMSGCLIENTLBSGETLBENTRIESRESPONSE
_CMSGCLIENTLBSGETLBENTRIESRESPONSE.fields_by_name['entries'].message_type = _CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetScore'] = _CMSGCLIENTLBSSETSCORE
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetScoreResponse'] = _CMSGCLIENTLBSSETSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetUGC'] = _CMSGCLIENTLBSSETUGC
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetUGCResponse'] = _CMSGCLIENTLBSSETUGCRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSFindOrCreateLB'] = _CMSGCLIENTLBSFINDORCREATELB
DESCRIPTOR.message_types_by_name['CMsgClientLBSFindOrCreateLBResponse'] = _CMSGCLIENTLBSFINDORCREATELBRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSGetLBEntries'] = _CMSGCLIENTLBSGETLBENTRIES
DESCRIPTOR.message_types_by_name['CMsgClientLBSGetLBEntriesResponse'] = _CMSGCLIENTLBSGETLBENTRIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientLBSSetScore = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetScore', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSSETSCORE,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetScore)
  })
_sym_db.RegisterMessage(CMsgClientLBSSetScore)

CMsgClientLBSSetScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetScoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSSETSCORERESPONSE,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetScoreResponse)
  })
_sym_db.RegisterMessage(CMsgClientLBSSetScoreResponse)

CMsgClientLBSSetUGC = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetUGC', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSSETUGC,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetUGC)
  })
_sym_db.RegisterMessage(CMsgClientLBSSetUGC)

CMsgClientLBSSetUGCResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetUGCResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSSETUGCRESPONSE,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetUGCResponse)
  })
_sym_db.RegisterMessage(CMsgClientLBSSetUGCResponse)

CMsgClientLBSFindOrCreateLB = _reflection.GeneratedProtocolMessageType('CMsgClientLBSFindOrCreateLB', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSFINDORCREATELB,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSFindOrCreateLB)
  })
_sym_db.RegisterMessage(CMsgClientLBSFindOrCreateLB)

CMsgClientLBSFindOrCreateLBResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSFindOrCreateLBResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSFINDORCREATELBRESPONSE,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSFindOrCreateLBResponse)
  })
_sym_db.RegisterMessage(CMsgClientLBSFindOrCreateLBResponse)

CMsgClientLBSGetLBEntries = _reflection.GeneratedProtocolMessageType('CMsgClientLBSGetLBEntries', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTLBSGETLBENTRIES,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntries)
  })
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntries)

CMsgClientLBSGetLBEntriesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSGetLBEntriesResponse', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY,
    '__module__' : 'steammessages_clientserver_lbs_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntriesResponse.Entry)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTLBSGETLBENTRIESRESPONSE,
  '__module__' : 'steammessages_clientserver_lbs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntriesResponse)
  })
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntriesResponse)
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntriesResponse.Entry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
